#
# spec file for package perl-Mail-DKIM
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           perl-Mail-DKIM
Version:        0.40
Release:        7.5
%define cpan_name Mail-DKIM
Summary:        Signs/verifies Internet mail with DKIM/DomainKey signatures
License:        GPL-2.0+
Group:          Development/Libraries/Perl
Url:            http://search.cpan.org/dist/Mail-DKIM/
#Source:         http://www.cpan.org/authors/id/J/JA/JASLONG/Mail-DKIM-0.39.tar.gz
Source:         %{cpan_name}-%{version}.tar.gz
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
%if 0%{?suse_version} && 0%{?suse_version} <= 1210
BuildRequires:  perl-macros
%endif
BuildRequires:  perl(Test::Simple)
#
BuildRequires:  perl(Crypt::OpenSSL::RSA) >= 0.24
BuildRequires:  perl(Digest::SHA)
BuildRequires:  perl(MIME::Base64)
BuildRequires:  perl(Mail::Address)
BuildRequires:  perl(Net::DNS)
#
Requires:       perl(Crypt::OpenSSL::RSA) >= 0.24
Requires:       perl(Digest::SHA)
Requires:       perl(MIME::Base64)
Requires:       perl(Mail::Address)
Requires:       perl(Net::DNS)
%{perl_requires}

%description
This module implements the various components of the DKIM and DomainKeys
message-signing and verifying standards for Internet mail. It currently
tries to implement these specifications:

* RFC4871, for DKIM

* RFC4870, for DomainKeys

The module uses an object-oriented interface. You use one of two different
classes, depending on whether you are signing or verifying a message. To
sign, use the the Mail::DKIM::Signer manpage class. To verify, use the the
Mail::DKIM::Verifier manpage class. Simple, eh?

%prep
%setup -q -n %{cpan_name}-%{version}
# disble policy.t, public_key.t in obs
%if ! %{with test}
%{__rm} t/policy.t
%{__rm} t/public_key.t
%endif

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%{__make} %{?_smp_mflags}

%check
%{__make} test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist
for script in dkimsign.pl dkimverify.pl; do
  %{__install} -D -m 0755 scripts/$script \
  %{buildroot}%{_bindir}/$script
done

%clean
%{__rm} -rf %{buildroot}

%files -f %{name}.files
%defattr(644,root,root,755)
%doc ChangeLog Changes HACKING.DKIM README TODO scripts
%defattr(-,root,root)
%{_bindir}/*

%changelog
* Wed Mar 27 2013 stefan.jakobs@rus.uni-stuttgart.de
- Update to version 0.40 - released 2013-02-07
  * New/changed functionality:
  * a single DNS resolver is created for the lifetime of the program,
    rather than reinitializing the resolver for each new query.
  * bugfixes:
  * fix the error message given when an invalid algorithm is
    specified in the construction of Mail::DKIM::Signer.
  * avoid Perl warning about use of an undefined value in several
    places (rt.cpan.org issue #82913).
  * speed- improved performance of parsing the message into lines
    (rt.cpan.org issue #77902). Patch by Mark Martinec.
  * fix DNS queries to use the correct method (txtdata) of Net::DNS
    (rt.cpan.org issue #83170). Patch by Mark Martinec.
  * API changes:
  * global subroutines resolver() or enable_EDNS0() in module
    Mail::DKIM::DNS can be called to specify non-default options
    to Net::DNS::Resolver (see also rt.cpan.org issue #80425).
* Fri Nov 18 2011 coolo@suse.com
- use original .tar.gz
* Mon Feb 21 2011 chris@computersalat.de
- removed author
* Mon Feb 21 2011 bjoern@cs.tu-berlin.de
- added scripts to {_bindir}
  o dkimsign.pl
  o dkimverify.pl
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Mon Nov 15 2010 varkoly@novell.com
-  update to 0.39
  * change in API Mail::DKIM::Canonicalization::Base::finish_header
  * Bugfixes
  o Mail::DKIM::Signer: fix an unusual error message given when no
    Key argument has been specified and it is time to load the key
  o Mail::DKIM::Verifier: fix an issue with getting wrong error
    codes when q= tag is broken.
* Mon Jul 26 2010 chris@computersalat.de
- fix build for o:F (1140)
  o added bcond_with test
    if not set policy.t, public_key.t test are disabled
* Wed Apr  7 2010 chris@computersalat.de
- update to 0.38
  * New/changed functionality:
  * DNS lookups can now be started asynchronously; the queries are
    created as the header is parsed; the results are not actually
    needed until the entire message has been read. (The Mail::DKIM
    module does not yet do the queries asynchrously; this is just
    the infrastructure so that the queries can be asynchronous in
    the future.)
  * bugfixes:
  * DNS lookup overrides alarm() signal (issue #2854325)
  * documentation updates:
  * document use of custom PrivateKey object, for external signing
  * describe how to get "pretty signatures" in Signer.pm
- cleanup spec
  o added norootforbuild
  o sort TAGS
  o macros
  o fixed deps
  o enabled testsuite
  - disabled tests with DNS (policy.t, public_key.t)
- added perl-macros
* Sun Feb 28 2010 varkoly@novell.com
- new version: 0.37
  * New/changed functionality:
  * ADSP records now check whether the domain itself exists, in
    accordance to the ADSP specification
  * support for ADSP (author-domain-signing-practices) records
  * removed support for pre-standardized DKIM signatures (i.e. these
    are DKIM signatures without a v= or bh= tag).
  * DNS resolver errors are detected and reported as such
  * API changes:
  * restore the as_string() method which was accidentally removed
    in version 0.34
  * renamed Mail::DKIM::Policy to Mail::DKIM::DkPolicy. Programs using
    the former name to create policy objects directly (though it would
    be more expected to fetch the objects through
    Mail::DKIM::Verifier) should update their code
  * new policies() method in Mail::DKIM::Verifier for fetching all
    applicable sender/author signing policies
  * bugfixes:
  * fixed regexp used to detect header field names (issue #2803465)
  * various fixes to ADSP checking
  * fixed a runaway regular expression in the canonicalization
    routines (patch provided by Mark Martinec)
  * Signer object would die if first line of input wasn't a header
    (rt.cpan.org issue #46179)
* Mon Jul 20 2009 varkoly@suse.de
- new version: 0.33
  * signature wrapping was still messed up, hopefully all bugs fixed now
  * signature wrapping would sometimes cause improper preparation of
    DKIM signatures, with "simple" canonicalization (issue #2257046)
  * test scripts:
  * the included corpus is now verified using a fake-DNS resolver,
    which means the test corpus can validate even when your DNS
    servers are really slow
* Mon Jan 26 2009 varkoly@suse.de
- bnc#469321 - Requirements not met within perl-Mail-DKIM
* Tue Oct 28 2008 varkoly@suse.de
- nwe version 0.32
  * removed requirement for Digest::SHA1 (issue #1832549).
    We now use the more capable Digest::SHA module for SHA-1 and SHA-256.
  * bugfixes:
  * granularity checking should be case-sensitive (issue #1938112).
  * identity tag now uses quoted-printable encoding (issue #1839015).
  * API improvement:
  * implemented identity_source() for DkSignature objects
* Wed Jul 16 2008 varkoly@suse.de
- Initial version of perl-Mail-DKIM
